import { Content, Header } from "antd/es/layout/layout";
import "./layout.less";
import { Menu } from "antd";
import { Footer } from "antd/lib/layout/layout";
import { Outlet, useNavigate } from "react-router";
import { HomeTwoTone } from "@ant-design/icons";
import { inject, observer } from "mobx-react";
import { Store } from "antd/es/form/interface";
import { useEffect } from "react";
const LayOut = (props: Store) => {
  const { usrStore } = props;
  const nav = useNavigate();
  useEffect(() => {
    if (usrStore.isNeedLogin) {
      nav("/login");
    }
  }, [usrStore,nav]);
  const items = [
    {
      key: "/admin/user",
      label: `用户管理`,
    },
    {
      key: "/admin/dep",
      label: `部门管理`,
    },
    {
      key: "/admin/archives",
      label: `档案管理`,
    },
    {
      key: "/admin/whseMgmt",
      label: `仓库管理`,
    },
    {
      key: "/admin/leaveApproval",
      label: `请假审批`,
    },
    {
      key: "/admin/politicalStudy",
      label: `政治学习`,
    },
    {
      key: `/admin/polRegulations`,
      label: `政治法规管理`,
    },
    {
      key: "/admin/materialMgmt",
      label: `物资管理`,
    },
    {
      key: "/admin/teamMgmt",
      label: `队伍属性管理`,
    },
    {
      key: "/admin/persMgmt",
      label: `个人身份管理`,
    },
  ];
  return (
    <div className="layout">
      <Header
        style={{
          position: "sticky",
          top: 0,
          zIndex: 1,
          width: "100%",
          display: "flex",
          alignItems: "center",
          padding: "0 10px",
        }}
      >
        <HomeTwoTone
          onClick={() => nav("/")}
          style={{ fontSize: "36px", marginRight: "10px" }}
        />
        <Menu
          theme="dark"
          mode="horizontal"
          defaultSelectedKeys={["/admin/user"]}
          items={items}
          onClick={(e) => {
            nav(e.key);
          }}
          style={{ flex: 1, minWidth: 0 }}
        />
      </Header>
      <Content style={{ padding: "0 20px" }}>
        <Outlet />
      </Content>
      <Footer style={{ textAlign: "center" }}>
        Ant Design ©{new Date().getFullYear()} Created by Ant UED
      </Footer>
    </div>
  );
};

export default inject("usrStore")(observer(LayOut));
