import { Button, Space, Modal, FormInstance, Flex } from "antd";
import { inject, observer } from "mobx-react";
import { useEffect, useState } from "react";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import FolderTwoTone from "@ant-design/icons/FolderOpenTwoTone";
import { folderConfig, catConfig, archiveConfig } from "./archives_conf";
const Archives = (props: Store) => {
  const { folderStore, acStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [tagId, setId] = useState<Number | null>(null);

  const onFinish = (values: any) => {
    let data = values;
    data.head_img = values.head_img[0].url;
    if (!tagId) {
      folderStore.add(data);
    } else {
      folderStore.putItem(tagId, data);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    folderStore.getlist();
    acStore.getlist();
  }, [folderStore, acStore]);

  // 添加事件
  const addHandler = () => {
    setProjectConfig(folderConfig);
    setIsModalOpen(true);
  };

  // 取消
  const cancelHandler = () => {
    setId(null);
    setIsModalOpen(false);
  };

  // 文件夹点击
  const folderHandle = () => {};
  const addCatHandler = () => {
    setProjectConfig(catConfig);
    setIsModalOpen(true);
  };

  const addArchivesHandler = () => {
    setProjectConfig(archiveConfig);
    setIsModalOpen(true);
  };
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button type="default" onClick={addHandler}>
            创建文件夹
          </Button>
          <Button type="default" onClick={addCatHandler}>
            添加档案类别
          </Button>
          <Button type="default" onClick={addArchivesHandler}>
            上传档案
          </Button>
        </Space>
        <Flex wrap gap="25px" justify="start">
          {Array.from({ length: folderStore.list?.length ?? 0 }, (_, i) => (
            <div key={i} onClick={folderHandle}>
              <FolderTwoTone rotate={-270} style={{ fontSize: "120px" }} />
              <p>{folderStore.list[i].folder_name}</p>
            </div>
          ))}
        </Flex>

        <Modal
          title={!tagId ? "添加文件夹" : "编辑文件夹"}
          width={600}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={cancelHandler}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {}}
            formName="card_basic"
            colProps={12}
            span={6}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject(...["archivesStore", "folderStore", "acStore"])(
  observer(Archives)
);
