import { Button, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";

const Dep = (props: Store) => {
  const { depStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [tagId, setId] = useState<Number | null>(null);
  const columns: ColumnsType<UserDataType> = [
    { title: "部门名称", dataIndex: "dep_name" },
    { title: "部门描述", dataIndex: "remark" },
    {
      title: "操作",
      dataIndex: "id",
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  edit(record);
                }}
              >
                编辑
              </Button>
              <Button
                type="dashed"
                danger
                size="small"
                onClick={() => {
                  depStore.deleteItem(record.id);
                }}
              >
                删除
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    let data = values
    data.head_img = values.head_img[0].url
    if (!tagId) {
      depStore.add(data);
    } else {
      depStore.putItem(tagId, data);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    depStore.getlist();
  }, [depStore]);
  const defaultConfig = [
    {
      type: "select",
      label: "上级部门名称",
      name: "pdep_id",
      value: "",
      selectUrl: "dep/list",
      rules: [{ required: false, message: "请输入上级部门!" }],
    },
    {
      type: "input",
      label: "部门名称",
      name: "dep_name",
      value: "",
      rules: [{ required: true, message: "请输入部门名称!" }],
    },
    {
      type: "input",
      label: "部门描述",
      name: "remark",
      value: "",
      rules: [{ required: true, message: "请输入部门描述" }],
    },
    {
      type: "upload",
      label: "头像",
      name: "head_img",
      value: [],
      rules: [{ required: false }],
    },
  ];
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button
            type="default"
            onClick={() => {
              setProjectConfig(defaultConfig);
              setId(null);
              setIsModalOpen(true);
            }}
          >
            添加
          </Button>
        </Space>

        <BTable store={depStore} columns={columns} dataSource={depStore.list} />
        <Modal
          title={!tagId ? "添加部门" : "编辑部门"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={4}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("depStore")(observer(Dep));
