import { Button, Image, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import "./user.less";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import { useNavigate } from "react-router";

const User = (props: Store) => {
  const { usrStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const nav = useNavigate();
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [userId, setId] = useState<Number | null>(null);
  const columns: ColumnsType<UserDataType> = [
    {
      title: "用户名",
      dataIndex: "user_name",
    },
    {
      title: "年龄",
      dataIndex: "age",
    },
    {
      title: "性别",
      dataIndex: "sex",
      render: (sex) => <span>{sex === "0" ? "男" : "女"}</span>,
    },
    {
      title: "头像",
      dataIndex: "head_img",
      render: (headImg) => <Image src={headImg}></Image>,
    },
    {
      title: "职位",
      dataIndex: "position",
    },
    {
      title: "备注",
      dataIndex: "remark",
    },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: {
        showTitle: false,
      },
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  edit(record);
                }}
              >
                编辑
              </Button>

              <Button
                type="dashed"
                danger
                size="small"
                onClick={() => {
                  usrStore.deleteItem(record.id);
                }}
              >
                删除
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    let data = {
      ...values,
    };
    data.head_img = values.head_img[0].url;
    if (!userId) {
      usrStore.add(values);
    } else {
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    usrStore.getlist();
  }, [usrStore]);
  const defaultConfig = [
    {
      type: "input",
      label: "用户名",
      name: "acount",
      value: "",
      rules: [{ required: true, message: "请输入人物名称!" }],
    },
    {
      type: "input",
      label: "年龄",
      name: "age",
      value: "",
      rules: [{ required: true, message: "请输入卡片内容" }],
    },
    {
      type: "input",
      label: "居住地",
      name: "address",
      value: "",
      rules: [{ required: true, message: "请输入卡片内容" }],
    },
    {
      type: "Radio",
      label: "性别",
      name: "sex",
      value: 0,
      rules: [{ required: true, message: "请输入卡片内容" }],
    },
    {
      type: "upload",
      label: "头像",
      name: "headImg",
      value: [],
      rules: [{ required: true, message: "请上传头像" }],
    },
    {
      type: "input",
      label: "角色",
      name: "role",
      value: "",
    },
  ];
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button
            type="default"
            onClick={() => {
              setProjectConfig(defaultConfig);
              setId(null);
              setIsModalOpen(true);
            }}
          >
            添加用户
          </Button>
          <Button
            type="default"
            onClick={() => {
              nav("/tag");
            }}
          >
            标签管理
          </Button>
        </Space>

        <BTable store={usrStore} columns={columns} dataSource={usrStore.list} />
        <Modal
          title={!userId ? "添加用户" : "编辑用户"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={4}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("usrStore")(observer(User));
