import { action, computed, makeObservable, observable } from "mobx";
// 用户信息
import baseHttp from "@/service/base";
import BaseStore from "./baseStore";
import { UserDataType, UserInfos } from "@/model/userModel";
class UserConfig {
    static LOGINURI: string = "anth/login"
    static LIST: string = "userMgmt/user/list"
    static ADD: string = "user"
    static DELETE: string = "user"
    static EDIT: string = "user"
}
class UserStore extends BaseStore<UserDataType> {
    _userinfo: UserInfos = {}; // 用户信息
    isNeedLogin: boolean = false; // 是否需要登录

    constructor() {
        super(UserConfig)
        makeObservable(this, {
            logOut: action,
            login: action,
            _userinfo: observable,
            isNeedLogin: observable,
            openLoginDilog: action,
            userInfo: computed,
        })
    }
    get userInfo(): UserInfos {
        if (!this._userinfo.token) {
            let token = window.localStorage.getItem("token")
            this._userinfo.token = token;
        }
        return this._userinfo;
    }
    logOut() {
        this._userinfo.token = "";
        window.localStorage.clear();
        this.item = "";
    }
    async login(params: UserInfos) {
        let param = {
            account: params.userName,
            password: params.passWord,
            genre: 1
        }
        try {
            let data = await baseHttp.post(UserConfig.LOGINURI, param)
            window.localStorage.setItem("token", data.data.token ?? "");
            return true
        } catch (error) {
            console.log(error)
            return false
        }
    }
    openLoginDilog() {
        this.isNeedLogin = true;
    }
    closeLoginDilog() {
        this.isNeedLogin = false;
    }
}
const userStore = new UserStore();
export default userStore;